@@ -3,13 +3,10 @@
 from __future__ import unicode_literals
 from flaky.flaky_decorator import flaky
 from flaky.names import FlakyNames
-from test.base_test_case import TestCase
+from test.test_case_base import TestCase
 
 
 class TestFlakyDecorator(TestCase):
-    def setUp(self):
-        super(TestFlakyDecorator, self).setUp()
-
     def test_flaky_raises_for_non_positive_min_passes(self):
         def test_something():
             pass
